<?php
if (! class_exists ( 'DTCoursePostType' )) {

	class DTCoursePostType {

		/**
		 * A function constructor calls initially
		 */
		function __construct() {

			// Add Hook into the 'init()' action
			add_action ( 'init', array ( $this, 'dt_init' ) );

			add_filter ( 'cs_metabox_options', array ( $this, 'dt_spa_course_cs_metabox_options' ) );			
		}

		function dt_init() {

			$postslug = naturalspa_cs_get_option( 'single-spa-course-slug', 'dt_spa_course' );

			$labels = array (
				'name' => esc_html__( 'Courses', 'designthemes-core' ),
				'all_items' => esc_html__( 'All Courses', 'designthemes-core' ),
				'singular_name' => esc_html__( 'Course', 'designthemes-core' ),
				'add_new' => esc_html__( 'Add New', 'designthemes-core' ),
				'add_new_item' => esc_html__( 'Add New Course', 'designthemes-core' ),
				'edit_item' => esc_html__( 'Edit Course', 'designthemes-core' ),
				'new_item' => esc_html__( 'New Course', 'designthemes-core' ),
				'view_item' => esc_html__( 'View Course', 'designthemes-core' ),
				'search_items' => esc_html__( 'Search Courses', 'designthemes-core' ),
				'not_found' => esc_html__( 'No Courses found', 'designthemes-core' ),
				'not_found_in_trash' => esc_html__( 'No Courses found in Trash', 'designthemes-core' ),
				'parent_item_colon' => esc_html__( 'Parent Course:', 'designthemes-core' ),
				'menu_name' => esc_html__( 'Courses', 'designthemes-core' ) ,					
			);

			$args = array ( 'labels' => $labels,
				'hierarchical' 		  => false,
				'supports' 			  => array ( 'title', 'editor', 'thumbnail','excerpt', 'revisions'),
				'public' 			  => true,
				'show_ui' 			  => true,
				'show_in_menu' 		  => false,
				'show_in_nav_menus'   => true,
				'publicly_queryable'  => true,
				'exclude_from_search' => false,
				'has_archive' 		  => true,
				'query_var' 	  	  => true,
				'can_export' 	  	  => true,
				'rewrite' 		  	  => array( 'slug' => $postslug ),
				'capability_type' 	  => 'post',
				'show_in_rest' 		  => true
			);

			register_post_type ( 'dt_spa_courses', $args );		
		}

		function dt_spa_course_cs_metabox_options( $options ) {

			$options[] = array(
				'id' => '_custom_settings',
				'title'     => esc_html__('Custom Options', 'designthemes-core'),
				'post_type' => 'dt_spa_courses',
				'context'   => 'normal',
				'priority'  => 'default',
				'sections'  => array(

					# Layout
					array( 'name'  => 'layout_section',
						'title' => esc_html__('Layout', 'naturalspa'),
						'icon'  => 'fa fa-columns',
						'fields' =>  array(
							array(
								'id'  => 'layout',
								'type' => 'image_select',
								'title' => esc_html__('Page Layout', 'naturalspa' ),
								'options'      => array(
									'content-full-width'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
									'with-left-sidebar'    => NATURALSPA_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
									'with-right-sidebar'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
								),
								'default'      => 'content-full-width',
								'attributes'   => array( 'data-depend-id' => 'page-layout' )
							),

							array(
								'id'        => 'show-standard-sidebar-left',
								'type'      => 'switcher',
								'title'     => esc_html__('Show Standard Left Sidebar', 'naturalspa' ),
								'dependency'  => array( 'page-layout', 'any', 'with-left-sidebar' ),
							),

							array(
								'id'  		 => 'widget-area-left',
								'type'  	 => 'select',
								'title' 	 => esc_html__('Choose Widget Area - Left Sidebar', 'designthemes-core'),
								'class'		 => 'chosen',
								'options'    => naturalspa_custom_widgets(),
								'attributes' => array(
									'multiple'  	   => 'multiple',
									'data-placeholder' => esc_attr__('Select Widget Areas', 'designthemes-core'),
									'style' 		   => 'width: 400px;'
								),
								'dependency' => array( 'page-layout', 'any', 'with-left-sidebar' ),
							),							

							array(
								'id'        => 'show-standard-sidebar-right',
								'type'      => 'switcher',
								'title'     => esc_html__('Show Standard Right Sidebar', 'naturalspa' ),
								'dependency'  => array( 'page-layout', 'any', 'with-right-sidebar' ),
							),

							array(
								'id'  		 => 'widget-area-right',
								'type'  	 => 'select',
								'title' 	 => esc_html__('Choose Widget Area - Right Sidebar', 'designthemes-core'),
								'class'		 => 'chosen',
								'options'    => naturalspa_custom_widgets(),
								'attributes' => array(
									'multiple'  	   => 'multiple',
									'data-placeholder' => esc_attr__('Select Widget Areas', 'designthemes-core'),
									'style' 		   => 'width: 400px;'
								),
								'dependency' => array( 'page-layout', 'any', 'with-right-sidebar' ),
							),
						)
					),

					# Others
					array( 'name' => 'others_section',
						'title' => esc_html__('Others','naturalspa'),
						'icon' => 'fa fa-cogs',
						'fields' => array(
							array(
								'id' => 'price',
								'type'  => 'text',
								'title' => esc_html__('Price', 'naturalspa' ),
								'before' => '<span style="font-size:17px;">'.paypal_currency_symbol( cs_get_option('currency') ).' </span>',
								'attributes' => array( 'style' => 'width:25%;')
							),
							
						    array(
						      'id'    => 'breadcrumb_background',
						      'type'  => 'background',
						      'title' => esc_html__('Breadcrumb Background', 'naturalspa' ),
						    ),
						)
					)
				)
			);			
			return $options;
		}
	}
}