<?php
if (! class_exists ( 'DTSpaProcedurePostType' )) {

	class DTSpaProcedurePostType {

		/**
		 * A function constructor calls initially
		 */
		function __construct() {

			// Add Hook into the 'init()' action
			add_action ( 'init', array ( $this, 'dt_init' ) );

			add_filter ( 'cs_metabox_options', array ( $this, 'dt_spa_procedure_cs_metabox_options' ) );
			
			add_filter( 'cs_framework_options', array( $this, 'dt_spa_procedure_cs_framework_options' ) );

		}

		function dt_init() {

			$postslug = naturalspa_cs_get_option( 'single-spa-procedure-slug', 'dt_spa_procedure' );

			$labels = array (
				'name' => esc_html__( 'Procedures', 'naturalspa' ),
				'all_items' => esc_html__( 'Procedures', 'naturalspa' ),
				'singular_name' => esc_html__( 'Procedure', 'naturalspa' ),
				'add_new' => esc_html__( 'Add New', 'naturalspa' ),
				'add_new_item' => esc_html__( 'Add New Procedure', 'naturalspa' ),
				'edit_item' => esc_html__( 'Edit Procedure', 'naturalspa' ),
				'new_item' => esc_html__( 'New Procedure', 'naturalspa' ),
				'view_item' => esc_html__( 'View Procedure', 'naturalspa' ),
				'search_items' => esc_html__( 'Search Procedures', 'naturalspa' ),
				'not_found' => esc_html__( 'No Procedures found', 'naturalspa' ),
				'not_found_in_trash' => esc_html__( 'No Procedures found in Trash', 'naturalspa' ),
				'parent_item_colon' => esc_html__( 'Parent Procedure:', 'naturalspa' ),
				'menu_name' => esc_html__( 'Procedures', 'naturalspa' ) ,					
			);

			$args = array ( 'labels' => $labels,
				'hierarchical' 		  => false,
				'supports' 			  => array ( 'title', 'editor', 'thumbnail','excerpt', 'revisions'),
				'public' 			  => true,
				'show_ui' 			  => true,
				'show_in_menu' 		  => 'dt_spa_module_menu_slug',
				'show_in_nav_menus'   => true,
				'publicly_queryable'  => true,
				'exclude_from_search' => false,
				'has_archive' 		  => true,
				'query_var' 	  	  => true,
				'can_export' 	  	  => true,
				'rewrite' 		  	  => array( 'slug' => $postslug ),
				'capability_type' 	  => 'post',
				'show_in_rest' 		  => true
			);

			register_post_type ( 'dt_spa_procedures', $args );			
		}

		function dt_spa_procedure_cs_metabox_options( $options ) {

			$options[] = array(
				'id' => '_custom_settings',
				'title'     => esc_html__('Custom Options', 'naturalspa'),
				'post_type' => 'dt_spa_procedures',
				'context'   => 'normal',
				'priority'  => 'default',
				'sections'  => array(

					# Layout
					array( 'name'  => 'layout_section',
						'title' => esc_html__('Layout', 'naturalspa'),
						'icon'  => 'fa fa-columns',
						'fields' =>  array(
							array(
								'id'  => 'layout',
								'type' => 'image_select',
								'title' => esc_html__('Page Layout', 'naturalspa' ),
								'options'      => array(
									'content-full-width'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
									'with-left-sidebar'    => NATURALSPA_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
									'with-right-sidebar'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
								),
								'default'      => 'content-full-width',
								'attributes'   => array( 'data-depend-id' => 'page-layout' )
							),

							array(
								'id'        => 'show-standard-sidebar-left',
								'type'      => 'switcher',
								'title'     => esc_html__('Show Standard Left Sidebar', 'naturalspa' ),
								'dependency'  => array( 'page-layout', 'any', 'with-left-sidebar' ),
							),

							array(
								'id'  		 => 'widget-area-left',
								'type'  	 => 'select',
								'title' 	 => esc_html__('Choose Widget Area - Left Sidebar', 'naturalspa'),
								'class'		 => 'chosen',
								'options'    => naturalspa_custom_widgets(),
								'attributes' => array(
									'multiple'  	   => 'multiple',
									'data-placeholder' => esc_attr__('Select Widget Areas', 'naturalspa'),
									'style' 		   => 'width: 400px;'
								),
								'dependency' => array( 'page-layout', 'any', 'with-left-sidebar' ),
							),							

							array(
								'id'        => 'show-standard-sidebar-right',
								'type'      => 'switcher',
								'title'     => esc_html__('Show Standard Right Sidebar', 'naturalspa' ),
								'dependency'  => array( 'page-layout', 'any', 'with-right-sidebar' ),
							),

							array(
								'id'  		 => 'widget-area-right',
								'type'  	 => 'select',
								'title' 	 => esc_html__('Choose Widget Area - Right Sidebar', 'naturalspa'),
								'class'		 => 'chosen',
								'options'    => naturalspa_custom_widgets(),
								'attributes' => array(
									'multiple'  	   => 'multiple',
									'data-placeholder' => esc_attr__('Select Widget Areas', 'naturalspa'),
									'style' 		   => 'width: 400px;'
								),
								'dependency' => array( 'page-layout', 'any', 'with-right-sidebar' ),
							),
						)
					),

					# Others
					array( 'name' => 'others_section',
						'title' => esc_html__('Others','naturalspa'),
						'icon' => 'fa fa-cogs',
						'fields' => array(
							array(
								'id' => 'price',
								'type'  => 'text',
								'title' => esc_html__('Price', 'naturalspa' ),
								'before' => '<span style="font-size:17px;">'.paypal_currency_symbol( cs_get_option('currency') ).' </span>',
								'attributes' => array( 'style' => 'width:25%;')
							),

							array(
								'id' => 'sub-title',
								'type'  => 'text',
								'title' => esc_html__('Sub Title', 'naturalspa' ),
								'attributes' => array( 'style' => 'width:100%;')
							),

							array(
								'id' =>  'agenda',
								'type'  => 'textarea',
								'title' => esc_html__('Agends', 'naturalspa' ),
								'desc' => esc_html( 'You can add agenda for this procedure. ( Note: separate values by commas (,) ) ', 'naturalspa')
							),							

						    array(
						      'id'    => 'breadcrumb_background',
						      'type'  => 'background',
						      'title' => esc_html__('Breadcrumb Background', 'naturalspa' ),
						    ),
						)
					)
				)
			);

			return $options;
		}

		function dt_spa_procedure_cs_framework_options( $options ) {
			
			$options[] = array(
				'name' => 'spa_module_options',
				'title' => esc_html__('Spa Module', 'naturalspa'),
				'icon' => 'fa fa-rocket',
				'sections' => array(
					array(
						'name' => 'spa_module_cpt_options',
						'title' => esc_html__('Custom Post Options', 'naturalspa'),
						'icon' => 'fa fa-heart',
						'fields' => array(

							array(
								'type'    => 'subheading',
								'content' => esc_html__( 'Archives Page Layout', 'naturalspa' ),
							),

							array(
								'id'      	 => 'spa-archives-page-layout',
								'type'         => 'image_select',
								'title'        => esc_html__('Page Layout', 'naturalspa'),
								'options'      => array(
									'content-full-width'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
									'with-left-sidebar'    => NATURALSPA_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
									'with-right-sidebar'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
								),
								'default'      => 'content-full-width',
								'attributes'   => array( 'data-depend-id' => 'spa-archives-page-layout' )
							),

							array(
								'id'  		 => 'show-standard-left-sidebar-for-spa-archives',
								'type'  		 => 'switcher',
								'title' 		 => esc_html__('Show Standard Left Sidebar', 'naturalspa'),
								'dependency'   => array( 'spa-archives-page-layout', 'any', 'with-left-sidebar' ),
							),

							array(
								'id'  		 => 'show-standard-right-sidebar-for-spa-archives',
								'type'  		 => 'switcher',
								'title' 		 => esc_html__('Show Standard Right Sidebar', 'naturalspa'),
								'dependency'   => array( 'spa-archives-page-layout', 'any', 'with-right-sidebar' ),
							),

							array(
								'type'    => 'subheading',
								'content' => esc_html__( 'Archives Post Layout', 'naturalspa' ),
							),

							array(
								'id'      	 => 'spa-archives-post-layout',
								'type'         => 'image_select',
								'title'        => esc_html__('Post Layout', 'naturalspa'),
								'options'      => array(
									'one-half-column'   => NATURALSPA_THEME_URI . '/cs-framework-override/images/one-half-column.png',
									'one-third-column'  => NATURALSPA_THEME_URI . '/cs-framework-override/images/one-third-column.png',
									'one-fourth-column' => NATURALSPA_THEME_URI . '/cs-framework-override/images/one-fourth-column.png',
								),
								'default'      => 'one-third-column',
							),

							array(
								'type'    => 'subheading',
								'content' => esc_html__( 'Permalinks', 'naturalspa' ),
							),

							array(
								'id'      => 'single-spa-course-slug',
								'type'    => 'text',
								'title'   => esc_html__('Single Course Slug', 'naturalspa'),
								'after'   => '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. spa-course-item', 'naturalspa').'<br> <b>'.esc_html__('After made changes save permalinks.', 'naturalspa').'</b></p>',
							),

							array(
								'id'      => 'single-spa-procedure-slug',
								'type'    => 'text',
								'title'   => esc_html__('Single Procedure Slug', 'naturalspa'),
								'after'   => '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. spa-procedure-item', 'naturalspa').'<br> <b>'.esc_html__('After made changes save permalinks.', 'naturalspa').'</b></p>',
							),

							array(
								'id'      => 'spa-stages-tax-slug',
								'type'    => 'text',
								'title'   => esc_html__('Stages Taxonomy Slug', 'naturalspa'),
								'after'   => '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. spa-stages', 'naturalspa').'<br> <b>'.esc_html__('After made changes save permalinks.', 'naturalspa').'</b></p>',
							),

							array(
								'id'      => 'spa-days-tax-slug',
								'type'    => 'text',
								'title'   => esc_html__('Days Taxonomy Slug', 'naturalspa'),
								'after'   => '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. spa-days', 'naturalspa').'<br> <b>'.esc_html__('After made changes save permalinks.', 'naturalspa').'</b></p>',
							),

							array(
								'id'      => 'spa-classes-tax-slug',
								'type'    => 'text',
								'title'   => esc_html__('Classes Taxonomy Slug', 'naturalspa'),
								'after'   => '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. spa-classes', 'naturalspa').'<br> <b>'.esc_html__('After made changes save permalinks.', 'naturalspa').'</b></p>',
							),

							array(
								'id'      => 'spa-periods-tax-slug',
								'type'    => 'text',
								'title'   => esc_html__('Periods Taxonomy Slug', 'naturalspa'),
								'after'   => '<p class="cs-text-info">'.esc_html__('Do not use characters not allowed in links. Use, eg. spa-periods', 'naturalspa').'<br> <b>'.esc_html__('After made changes save permalinks.', 'naturalspa').'</b></p>',
							),							
						)
					),
					array(
						'name' => 'spa_module_paypal_options',
						'title' => esc_html__('Paypal', 'naturalspa'),
						'icon' => 'fa fa-paypal',
						'fields' => array(

							array(
								'type'      => 'notice',
								'class'     => 'success',
								'content'   => __('Used in Spa course module','naturalspa'),
							),

							array(
								'id'  		 => 'enable-paypal',
								'type'  	 => 'switcher',
								'title' 	 => esc_html__('Enable Paypal Module', 'naturalspa'),
							),

							array(
								'id'      => 'paypal-email',
								'type'    => 'text',
								'title'   => esc_html__('Account Email ID', 'naturalspa'),
								'info'   => esc_html__('Enter a valid Merchant account ID or PayPal account email address. All payments will go to this account.', 'naturalspa'),
								'dependency'   => array( 'enable-paypal', '==', 'true' ),
							),

							array(
								'id' => 'currency',
								'type' => 'select',
								'title'   => esc_html__('Currency', 'naturalspa'),
								'default' => 'AUD',								
								'options' => paypal_currencies()
							),

							array(
								'id' => 'language',
								'type' => 'select',
								'title'   => esc_html__('Language', 'naturalspa'),								
								'dependency'   => array( 'enable-paypal', '==', 'true' ),
								'options' => array_unique( array(
									"da_DK" => __('Danish','naturalspa'),
									"nl_BE" => __('Dutch','naturalspa'),
									"EN_US" => __('English','naturalspa'),
									"en_GB" => __('English - UK','naturalspa'),
									"fr_CA" => __('French','naturalspa'),
									"de_DE" => __('German','naturalspa'),
									"he_IL" => __('Hebrew','naturalspa'),
									"it_IT" => __('Italian','naturalspa'),
									"ja_JP" => __('Japanese','naturalspa'),
									"no_NO" => __('Norwgian','naturalspa'),
									"pl_PL" => __('Polish','naturalspa'),
									"pt_BR" => __('Portuguese','naturalspa'),
									"ru_RU" => __('Russian','naturalspa'),
									"es_ES" => __('Spanish','naturalspa'),
									"sv_SE" => __('Swedish','naturalspa'),
									"zh_CN" => __('Simplified Chinese -China only','naturalspa'),
									"zh_HK" => __('Traditional Chinese - Hong Kong only','naturalspa'),
									"zh_TW" => __('Traditional Chinese - Taiwan only','naturalspa'),
									"tr_TR" => __('Turkish','naturalspa'),
									"th_TH" => __('Thai','naturalspa')
								) )
							),

							array(
								'id'  		 => 'enable-paypal-live',
								'type'  	 => 'switcher',
								'dependency'   => array( 'enable-paypal', '==', 'true' ),
								'title' 	 => esc_html__('Enable Paypal Live', 'naturalspa'),
							),														
						)						
					),					
				)				
			);

			return $options;
		}
	}
}